@@ -1,11 +1,11 @@
+#!/usr/bin/env python
+
 import os
 import sys
+import multiprocessing
 
 from django.conf import settings
 
-from django_coverage.coverage_runner import CoverageRunner
-from django_nose import NoseTestSuiteRunner
-
 
 EXTERNAL_APPS = [
     'django.contrib.admin',
@@ -32,6 +32,7 @@ if not settings.configured:
             }
         },
         INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS,
+        ROOT_URLCONF='posts.tests.urls',
         TEMPLATE_DIRS = (
             os.path.join(os.path.dirname(__file__), '../templates'),
         ),
@@ -40,6 +41,9 @@ if not settings.configured:
     )
 
 
+from django_coverage.coverage_runner import CoverageRunner
+from django_nose import NoseTestSuiteRunner
+
 class NoseCoverageTestRunner(CoverageRunner, NoseTestSuiteRunner):
     pass
 
